import os
import multiprocessing
import pickle

from multiprocessing import Process
from utility.file_finder import file_search

from hwp_convert_code.excute.error_manage.hwp_convert_error import ConvertSettingFileError
from hwp_convert_code.excute.file_converting.hwp_to_html_convert import HWPConvert
from hwp_convert_code.excute.file_converting.hwp_to_pdf_convert import HwpToPdfConvert
from hwp_convert_code.excute.file_converting.pdf_to_html_convert import PDFConvert
from hwp_convert_code.excute.error_manage.data_parsing_error import NotAllowedExtensionError
from utility.my_log import myLog

class DataConverting(multiprocessing.Process):
    def __init__(self, session_key, convert_before_file_location, convert_after_file_location):
        super(DataConverting, self).__init__()

        self.DATA_PARSING_SETTING_FILE_NAME = None
        self.DATA_PARSING_SETTING_FILE_LOCATION = None
        self._DATA_PARSING_SETTING_FILE_CONTENT = None

        self.CONVERT_BEFORE_FILE_LOCATION = convert_before_file_location
        self.CONVERT_BEFORE_EXTENSION = None
        self.CONVERT_AFTER_FILE_LOCATION = convert_after_file_location
        self.CONVERT_AFTER_EXTENSION = None

        self.NUMBER_OF_CONVERT_FILE = 0
        self.NUMBER_OF_THREADING = 1

        self.CONVERT_BEFORE_EXTENSION = "hwp"
        self.CONVERT_AFTER_EXTENSION = "html"

        self.log = myLog(project_name="hwp-parsing-api", run_file_location=__file__, save_file_location="hwp_convert_code/logs/file_convert_log")

        self.MULTI_METHOD = "multiprocess"
        self.NUMBER_OF_THREADING = 24
        self.NUMBER_OF_CONVERT_FILE = 0
        self.session_key = session_key
        self.work_process = {}

    def _execute_convert_file__multiprocess(self, file_type, convert_file_location, convert_after_file_location, replace_extension):
        data_convert_instance = HWPConvert(convert_file_location, convert_after_file_location, replace_extension=replace_extension)
        data_convert_instance.run()

    def _parsing_thread_scheduling(self, convert_file_location_list):
        end_work_count = 0
        now_executing_thread = 0
        data_convert_thread_list = []

        self.log.info(f"병렬처리 방법 : {self.MULTI_METHOD}\n")
        self.log.info(f"{self.MULTI_METHOD} 동작 수 : {self.NUMBER_OF_THREADING}\n")

        for convert_file_location in convert_file_location_list:
            file_extension = convert_file_location.split(".")[-1]
            if len(file_extension) > 4:
                file_extension = ""

            if (self.CONVERT_BEFORE_EXTENSION.lower() == "hwp" or self.CONVERT_BEFORE_EXTENSION.lower() == "all") and file_extension == "hwp":
                converted_file_list = file_search(self.CONVERT_AFTER_FILE_LOCATION, print_location=False)
                if convert_file_location.split("/")[-1] + ".html" in converted_file_list:
                    continue

                self.log.info(f"파일 변환 {self.MULTI_METHOD} 준비중.. [{convert_file_location}]")
                data_convert_instance = Process(target=self._execute_convert_file__multiprocess, args=('hwp', convert_file_location, self.CONVERT_AFTER_FILE_LOCATION, self.CONVERT_AFTER_EXTENSION))
                data_convert_thread_list.append(data_convert_instance)

            else:
                raise NotAllowedExtensionError

            self.log.info(f"파일 변환 {self.MULTI_METHOD} 시작 [{data_convert_thread_list[-1].name}]")

            data_convert_thread_list[-1].start()
            now_executing_thread += 1

            while True:
                convert_thread_alive_list = [[i_index, i.is_alive()] for i_index, i in enumerate(data_convert_thread_list)]
                convert_thread_alive_list.reverse()

                for thread_alive_info in convert_thread_alive_list:
                    if thread_alive_info[1] is False:
                        now_executing_thread -= 1
                        end_work_count += 1

                        self.work_process[self.session_key] = {
                            "all_process_number" : len(convert_file_location_list),
                            "complate_process_number" : end_work_count
                        }

                        with open("hwp_convert_code/pipeline.pl", "wb") as write_file:
                            pickle.dump(self.work_process, write_file)

                        self.log.info(f"파일 변환 {self.MULTI_METHOD} 종료 [{data_convert_thread_list[thread_alive_info[0]].name}]")

                        del data_convert_thread_list[thread_alive_info[0]]

                if now_executing_thread != self.NUMBER_OF_THREADING:
                    break

        for convert_thread in data_convert_thread_list:
            convert_thread.join()
            end_work_count += 1

            self.work_process[self.session_key] = {
                "all_process_number": len(convert_file_location_list),
                "complate_process_number": end_work_count
            }

            with open("hwp_convert_code/pipeline.pl", "wb") as write_file:
                pickle.dump(self.work_process, write_file)


    def run(self):
        self.log.info("----------데이터 변환 시작----------")
        if self.CONVERT_AFTER_EXTENSION == "html":
            self.log.info(" --> HWP/PDF to HTML")
            self._document_to_html()

        else:
            self.log.info("설정파일 에러")
            raise ConvertSettingFileError("변환후확장자", self.CONVERT_AFTER_EXTENSION)


    def _document_to_html(self):
        extension_list = []

        if self.CONVERT_BEFORE_EXTENSION == "all":
            extension_list = ["hwp", "pdf"]
        else:
            extension_list.append(self.CONVERT_BEFORE_EXTENSION)

        convert_file_location_list = file_search(self.CONVERT_BEFORE_FILE_LOCATION, extension=extension_list, include_in_directory=True)

        if len(convert_file_location_list) > self.NUMBER_OF_CONVERT_FILE and self.NUMBER_OF_CONVERT_FILE not in [None, "None", "null", "", 0]:
            convert_file_location_list = convert_file_location_list[:self.NUMBER_OF_CONVERT_FILE]

        self.work_process[self.session_key] = {
            "all_process_number": len(convert_file_location_list),
            "complate_process_number": 0
        }

        with open("hwp_convert_code/pipeline.pl", "wb") as write_file:
            pickle.dump(self.work_process, write_file)

        self._parsing_thread_scheduling(convert_file_location_list)




import random
import datetime
from filelock import Timeout, FileLock
import shutil

import copy
import os
import glob
import subprocess
import threading
import zlib
from contextlib import closing
from functools import partial

from docopt import docopt
from lxml.etree import XMLSyntaxError

import hwp_convert_code.excute.file_converting.config as cf

from hwp5.hwp5html import HTMLTransform, wrap_for_css, wrap_for_xml, open_dir
from hwp5.proc import rest_to_docopt, version, init_logger
from hwp5.utils import make_open_dest_file
from hwp5.xmlmodel import Hwp5File

from hwp_convert_code.excute.error_manage.hwp_convert_error import RegistryRegistrationError

now = datetime.datetime.now()

'''
* HWP 문서를 Html 문서로 변환하는 프로그램
'''


class HWPConvert(threading.Thread):
    def __init__(self, slash, target_file_name, save_location, replace_extension="html", password=""):
        self.CODEC = "utf-8"
        self.PASSWORD = password
        self.SLASH = slash
        self.TARGET_FILE_NAME = target_file_name
        self.REPLACE_FILE_NAME = target_file_name.split(slash)[-1].split(".hwp")[0] + "." + replace_extension
        self.SAVE_LOCATION = save_location  # if save_location[-1] in ["\\", "/"] else save_location + "/"
        self.EXTENSION = replace_extension
        self.HWP_SECURE_REGISTRY_NAME = "FilePathCheckerModule"

        threading.Thread.__init__(self)

    # 현재 실행중인 프로세스의 정보를 가져옴
    def __get_execute_process_list(self):
        process_dict = {}
        all_process_list = [line.split() for line in
                            subprocess.check_output(["tasklist", "/V"], encoding="cp949").splitlines()]

        for i in all_process_list[3:]:
            process_dict.setdefault(i[0], [])
            in_list = process_dict.get(i[0])

            name_index = 0
            origin_info = copy.deepcopy(i)
            for j_index, j in enumerate(reversed(origin_info)):
                if j.find(":") != -1:
                    name_index = len(origin_info) - j_index
                    break

            process_name = " ".join(i[name_index:])

            for j in origin_info[name_index:]:
                del i[name_index]
            i.append(process_name)

            in_list.append(i)

        return process_dict

    def __get_process_name(self):
        filename = self.TARGET_FILE_NAME.split("/")[-1]
        file_location = self.TARGET_FILE_NAME.replace(filename, "").replace("/", "\\")
        return f"{filename} [{file_location}] - 한글"

    def hwp_to_html(self):
        log_path = cf.path.log_path

        __doc__ = '''HWPv5 to HTML converter

        Usage::

            hwp5html [options] <hwp5file>
            hwp5html [options] <hwp5file> --html
            hwp5html [options] <hwp5file> --css
            hwp5html -h | --help
            hwp5html --version

        Options::

            -h --help           Show this screen
            --version           Show version
            --loglevel=<level>  Set log level.
            --logfile=<file>    Set log file.

            --output=<output>   Output file / directory'''

        doc = rest_to_docopt(__doc__)
        args = docopt(doc, argv=[self.TARGET_FILE_NAME], version=version)
        init_logger(args)

        hwp5path = args['<hwp5file>']

        html_transform = HTMLTransform()

        open_dest = make_open_dest_file(args['--output'])
        if args['--css']:
            transform = html_transform.transform_hwp5_to_css
            open_dest = wrap_for_css(open_dest)

        elif args['--html']:
            transform = html_transform.transform_hwp5_to_xhtml
            open_dest = wrap_for_xml(open_dest)

        else:
            transform = html_transform.transform_hwp5_to_dir
            dest_path = self.SAVE_LOCATION + self.REPLACE_FILE_NAME

            if not (os.path.isdir(dest_path)):
                os.makedirs(os.path.join(dest_path))

            if not dest_path:
                dest_path = os.path.splitext(os.path.basename(hwp5path))[0]
            open_dest = partial(open_dir, dest_path)

        with closing(Hwp5File(hwp5path)) as hwp5file:
            with open_dest() as dest:
                try:
                    transform(hwp5file, dest)
                except XMLSyntaxError as syntax_error:
                    print(syntax_error)
                    log = open(log_path + 'log.txt', 'a')
                    log.write('SYNTAX_ERROR!:' + str(dest_path) + '\n')
                    log.close()
                    pass

    def run(self):
        self.hwp_to_html()


def path_list(o_path, iswin):
    if iswin == 'test':
        slash = '\\'
    elif iswin == 'linux':
        slash = '/'
    elif iswin == 'home':
        slash = '\\'
    else:
        print('os 입력이 잘못되었습니다.')

    first_path = os.listdir(o_path)

    second_path = []

    for i in range(len(first_path)):
        path_temp = str(o_path + first_path[i] + slash)
        second_path.append(path_temp)

        third_path = []
        for pth in second_path:
            if len(os.listdir(pth)) > 1:
                path_temp = sorted(os.listdir(pth))
                third_path.append(pth + path_temp[-1] + slash + '한글' + slash + '*.hwp')
            elif len(os.listdir(pth)) == 1:
                path_temp = sorted(os.listdir(pth))
                third_path.append(pth + path_temp[0] + slash + '한글' + slash + '*.hwp')
            else:
                continue

    final_path = []
    for i in range(len(third_path)):
        final_path_tmp = sorted(glob.glob(third_path[i]))
        final_path.extend(final_path_tmp)

    return final_path, slash


def run_list(i_process, path):
    # 경로 지정
    if path == 'test':
        test_path = cf.test_path
        input_path = test_path.targetPattern
        print('input_path : ' + input_path)
        output_path = test_path.output_path
        print('output_path : ' + output_path)
        log_path = test_path.log_path  # todo 로그 경로 추가
        lock_path = test_path.lock_path

    elif path == 'linux':
        linux_path = cf.path
        input_path = linux_path.targetPattern
        print('input_path : ' + input_path)
        output_path = linux_path.output_path
        print('output_path : ' + output_path)
        log_path = linux_path.log_path  # todo 로그 경로 추가
        lock_path = linux_path.lock_path

    elif path == 'home':
        home_path = cf.home_path
        input_path = home_path.targetPattern
        # print('input_path : ' + input_path)
        output_path = home_path.output_path
        # print('output_path : ' + output_path)
        log_path = home_path.log_path

    else:
        print('run_list : path error')

    result, slsh = path_list(input_path, path)
    # print('total hwp : ' + str(len(result)))


    if not (os.path.isdir(log_path)):
        try:
            os.makedirs(os.path.join(log_path))
        except FileExistsError:
            print('create log.txt error')

    # log.txt에 발견한 hwp 갯수 생성
    with open(log_path + 'log.txt', 'a') as log:
        log.write('total hwp : ' + str(len(result)) + '\n')
        log.write(now.strftime('%Y-%m-%d %H:%M:%S') + '\n')

    # 해당 경로에 존재하는 모든 hwp파일을 불러와 html 변환
    # for res in result:
    for i in range(len(result)):
        css_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'styles.css'
        bin_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'bindata'

        if os.path.isfile(css_path):
            try:
                os.remove(css_path)
            except FileNotFoundError as ff:
                print(ff)
                pass

        if os.path.isdir(bin_path):
            try:
                shutil.rmtree(bin_path)
            except FileNotFoundError as ff:
                print(ff)
                pass

        message = '#### prcs_id : ' + str(i_process) + ' #### ' + result[i]
        # txt_path = result[i].split(".hwp")[0] + '.txt'
        txt_path = output_path + 'txt' + slsh + result[i].split(slsh)[-1].split('.hwp')[0] + '.txt'
        output_txt_path = output_path + 'txt' + slsh

        if not (os.path.isdir(output_txt_path)):
            try:
                os.makedirs(os.path.join(output_txt_path))
            except FileExistsError:
                print('')
                pass

        if os.path.isfile(txt_path):
            continue

        elif not os.path.isfile(txt_path):
            # print(str(i_process) + '@@ ' + txt_path, flush=True)
            if not (os.path.isdir(lock_path)):
                try:
                    os.makedirs(os.path.join(lock_path))
                except FileExistsError:
                    pass


            lock_file_path = lock_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.lock'
            lock = FileLock(lock_file_path)

            with lock:
                if os.path.isfile(txt_path):
                    continue
                f = open(txt_path, 'w')
                f.close()

                print(message + '\n', flush=True)

                try:
                    html_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html'
                    if os.path.isdir(html_path):
                        continue
                    else:
                        hwp_convert = HWPConvert(slash=slsh,
                                                 target_file_name=result[i],
                                                 save_location=output_path,
                                                 replace_extension="html")
                        hwp_convert.run()

                except zlib.error as e:
                    print(e)

                except XMLSyntaxError as syntax_error:
                    print(syntax_error)
                    log = open(log_path + 'log.txt', 'a')
                    log.write('SYNTAX_ERROR2!:' + str(html_path) + '\n')
                    log.write(str(syntax_error) + '\n')
                    log.close()
                    continue

                try:
                    log = open(log_path + 'log.txt', 'a')
                    log.write(message + '\n')
                finally:
                    log.close()

                # time.sleep(0.1)

            # todo .html 폴더 내부 css파일 bin 폴더 등 필요없는 것 삭제

            css_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'styles.css'
            bin_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'bindata'

            try:
                os.remove(css_path)
            except FileNotFoundError as ff:
                print(ff)
                pass

            try:
                shutil.rmtree(bin_path)
                lock_file_path = lock_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.lock'
                os.remove(lock_file_path)

            except FileNotFoundError as ff:
                print(ff)
                pass

    # for root, dirs, files in os.walk(output_path):
    #     rootpath = os.path.join(os.path.abspath(output_path), root)
    #
    #     for file in files:
    #         filepath = os.path.join(rootpath, file)
    #         res.append(filepath)
    #
    #     for result in res:
    #         print(result)
    #         file_name = result.split("/")[-1]
    #         file_path = os.path.join()


def test_path(i_process, path):
    if path == 'test':
        test_path = cf.test_path
        input_path = test_path.targetPattern
        print('input_path : ' + input_path)
        output_path = test_path.output_path
        print('output_path : ' + output_path)
        # log_path = test_path.log_path #todo 로그 경로 추가
        # lock_path = cf.home_path.lock_path

    elif path == 'linux':
        linux_path = cf.path
        input_path = linux_path.targetPattern
        print('input_path : ' + input_path)
        output_path = linux_path.output_path
        print('output_path : ' + output_path)
        # log_path = linux_path.log_path #todo 로그 경로 추가
        # lock_path = cf.home_path.lock_path

    elif path == 'home':
        home_path = cf.home_path
        input_path = home_path.targetPattern
        # print('input_path : ' + input_path)
        output_path = home_path.output_path
        # print('output_path : ' + output_path)
        log_path = home_path.log_path

    else:
        print('test_path : path error')

    result, slsh = path_list(input_path, path)
    print('total hwp : ' + str(len(result)))

    with open(log_path, 'a') as log:
        log.write('total hwp : ' + str(len(result)) + '\n')

    for i in range(len(result)):
        txt_path = result[i].split(".hwp")[0] + '.txt'

        if os.path.isfile(txt_path):
            continue

        elif not os.path.isfile(txt_path):
            # print(str(i_process) + '@@ ' + txt_path, flush=True)
            # lock = FileLock(lock_path)

            with lock:
                print(str(i_process) + '<- ' + result[i], flush=True)
                if os.path.isfile(txt_path):
                    continue

                f = open(txt_path, 'w')
                f.close()

                message = '#### prcs_id : ' + str(i_process) + ' #### ' + result[i]

                try:
                    log = open(log_path, 'a')
                    log.write(message + '\n')
                finally:
                    log.close()

                # time.sleep(0.1)


def rm_txt(path):
    if path == 'test':
        test_path = cf.test_path
        input_path = test_path.targetPattern
        print('input_path : ' + input_path)
        output_path = test_path.output_path
        print('output_path : ' + output_path)
        # log_path = test_path.log_path #todo 로그 경로 추가
        lock_path = cf.home_path.lock_path

    elif path == 'linux':
        linux_path = cf.path
        input_path = linux_path.targetPattern
        print('input_path : ' + input_path)
        output_path = linux_path.output_path
        print('output_path : ' + output_path)
        # log_path = linux_path.log_path #todo 로그 경로 추가
        lock_path = cf.home_path.lock_path

    elif path == 'home':
        home_path = cf.home_path
        input_path = home_path.targetPattern
        # print('input_path : ' + input_path)
        output_path = home_path.output_path
        # print('output_path : ' + output_path)
        log_path = home_path.log_path

    else:
        print('rm_txt : path error')

    result, slsh = path_list(input_path, path)
    # 임시 텍스트함수 제거
    for i in range(len(result)):
        txt_path = output_path + 'txt' + slsh + result[i].split(slsh)[-1].split('.hwp')[0] + '.txt'
        # css_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'styles.css'
        # bin_path = output_path + result[i].split(slsh)[-1].split('.hwp')[0] + '.html' + slsh + 'bindata'

        if os.path.isfile(txt_path):
            os.remove(txt_path)
        # os.remove(css_path)
        # os.rmdir(bin_path)

    print('block 텍스트파일 제거완료')



## 대상정의 세팅파일 관련 에러
class PreprocessShapeError(Exception):
    def __str__(self):
        return '클랜징 설정파일(preprocessing_shape.json)의 "전처리형태" 값이 존재하지 않습니다.'


class CleansingFormFileContentError(Exception):
    def __str__(self):
        return '클랜징 설정파일(preprocessing_shape.json)의 "전처리대상정의" 또는 "전처리대상매핑" 값이 존재하지 않습니다.'


class ColumnNameNotMatchedError(Exception):
    def __str__(self):
        return '설정파일의 Database Column 명이 올바르지 않습니다.'


class TableNameNotFoundError(Exception):
    def __str__(self):
        return '클랜징 설정파일(preprocessing_shape.json)의 "테이블 명" 값이 존재하지 않습니다.'


## 전처리형태 세팅파일 관련 에러
class PreprocessTargetDefError(Exception):
    def __str__(self):
        return '클랜징 설정파일(preprocessing_target_def.json)의 "대상정의" 값이 존재하지 않습니다.'


## ETC
class SQLProgrammingError(Exception):
    def __str__(self):
        return 'SQL이 올바르지 않습니다.'


class PreprocessShapeNotMatchedError(Exception):
    def __str__(self):
        return '설정파일의 전처리 형태가 매칭되지 않습니다.'


import threading
import time

from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
from pdfminer.converter import TextConverter, XMLConverter, HTMLConverter
from pdfminer.layout import LAParams
from pdfminer.pdfpage import PDFPage
from io import BytesIO

class PDFConvert(threading.Thread):
    def __init__(self, target_file_name, save_location, replace_extension="html", password=""):
        pass


import multiprocessing


class test_path:
    output_path = '/opt/HEQMS/convert/output/'
    targetPattern = r"D:\\NCS\\hwp\\"
    # lock_path = 'C:\\Python\\NCS\\log\\lock.txt'
    # log_path = 'C:\\Python\\NCS\\log\\log.txt'


class path:
    output_path = '/opt/test/output/'
    targetPattern = r"/opt/test/"
    lock_path = '/opt/HEQMS/lock/'
    log_path = '/opt/test/output/log/'

class home_path:
    output_path = 'C:\\Python\\NCS\\output\\'
    targetPattern = r"C:\\Python\\NCS_data\\"
    lock_path = 'C:\\Python\\NCS\\log\\lock.txt'
    log_path = 'C:\\Python\\NCS\\log\\log.txt'


class prcs:
    cpu_num = multiprocessing.cpu_count()



class NotAllowedExtensionError(Exception):
    def __init__(self, arg=None):
        self.arg = arg

    def __str__(self):
        return f"설정파일의 '변환전확장자' 옵션이 허용되지 않습니다."


class WrongFileExtensionError(Exception):
    def __init__(self, arg=None):
        self.arg = arg

    def __str__(self):
        return f"설정파일의 '원본파일형태' 옵션이 올바르지 않습니다. '원본파일형태' 옵션은 hwp 및 pdf 두가지의 옵션만 지원합니다."

class FileShapeNotFoundError(Exception):
    def __init__(self, arg=None):
        self.arg = arg

    def __str__(self):
        return f"설정파일의 '파일형태' 옵션이 존재하지 않습니다."

class WrongFileStructureError(Exception):
    def __init__(self, arg=None):
        self.arg = arg

    def __str__(self):
        return f"설정파일의 '파일형태' 옵션이 올바르지 않습니다."

class WrongSettingFileError(Exception):
    def __init__(self, arg=None):
        self.arg = arg

    def __str__(self):
        return f"설정파일의 'tag'값 또는 'name'값이 존재하지 않습니다."


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(

    name="hthPkg",

    version="0.0.33",

    install_requires=[
            "Django==3.0.3",
            "configparser==4.0.2",
            "django-cors-headers==3.2.1",
            "djangorestframework==3.11.0",
            "pycryptodome==3.9.7",
            "mysqlclient==1.4.6",
            "sqlalchemy==1.3.13",
            "pdfminer.six==20191110",
            "requests==2.22.0",
            "six==1.13.0",
            "xlrd==1.2.0",
            "XlsxWriter==1.2.3",
            "pymysql==0.9.3",
            "lxml==4.4.2",
            "pyhwp==0.1b12",
            "BeautifulSoup4==4.8.2",
            "filelock==3.0.12",
        ],

    author="Example Author",

    author_email="author@example.com",

    description="A small example package",

    long_description=long_description,

    long_description_content_type="text/markdown",

    url="https://github.com/pypa/sampleproject",

    packages=setuptools.find_packages(),

    classifiers=[

        "Programming Language :: Python :: 3",

        "License :: OSI Approved :: MIT License",

        "Operating System :: OS Independent",

    ],
    python_requires='>=3.6',

)



import copy
import os
import subprocess
import threading

from hwp_convert_code.excute.error_manage.hwp_convert_error import RegistryRegistrationError

class HwpToPdfConvert(threading.Thread):

    def __init__(self, target_file_name, save_location, replace_extension="html", password=""):
        pass


class RegistryRegistrationError(Exception):
    def __init__(self, arg):
        self.arg = arg

    def __str__(self):
        return f"'{self.arg}' Registry가 등록 되어있지 않습니다."

class ConvertSettingFileError(Exception):
    def __init__(self, arg1, arg2):
        self.arg1 = arg1
        self.arg2 = arg2

    def __str__(self):
        return f"'{self.arg1}' paramter의 값이 '{self.arg2}'로 잘못되었습니다. "


from multiprocessing import Process
import warnings
import time

import hwp_convert_code.excute.file_converting.config as cf
import hwp_convert_code.excute.file_converting.hwp_to_html_convert as hth

# 경고문구 제거
warnings.filterwarnings(action='ignore')

i_cpu = cf.prcs.cpu_num
# print('core num : ' + str(i_cpu + 2))

# 멀티 쓰레딩 Process 사용
procs = []

# 시작시간
start_time = time.time()

if __name__ == '__main__':
    for i_process in range(i_cpu):
        # Process 객체 생성
        # proc = Process(target=hth.test_path, args=(i_process, 'test'))
        # proc = Process(target=hth.test_path, args=(i_process, 'home')) #todo 제거하기
        proc = Process(target=hth.run_list, args=(i_process, 'linux'))  # todo 제거하기
        procs.append(proc)
        proc.start()

    # 프로세스 종료 대기
    for proc in procs:
        proc.join()

    # hth.rm_txt('test')
    hth.rm_txt('linux') #todo 제거하기

# 종료시간
print("--- %s seconds ---" % (time.time() - start_time))